==> pyppbox-3.0b4.tar.gz: pyppbox-3.0b4/README.md <==
# 🐍📦 [**pyppbox**](https://github.com/rathaumons/pyppbox)

<div align="center">

[![Documentation](https://github.com/rathaumons/pyppbox/actions/workflows/pyppboxdocs.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/pyppboxdocs.yaml) [![Build PyPI](https://github.com/rathaumons/pyppbox/actions/workflows/build_pypi.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/build_pypi.yaml) [![Test Build](https://github.com/rathaumons/pyppbox/actions/workflows/test_build.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/test_build.yaml)

[![Test Core Windows](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_windows.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_windows.yaml) [![Test Core Linux](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_linux.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_linux.yaml) [![Test Core macOS](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_macos.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_macos.yaml)

<img src="https://raw.githubusercontent.com/rathaROG/screenshot/master/pyppbox/pyppbox_new_wide.png"><br />

**[📗 Documentation](https://rathaumons.github.io/pyppbox/) > [🚀 Getting started](https://rathaumons.github.io/pyppbox/getstarted.html) > [💡 Examples](https://rathaumons.github.io/pyppbox/examples.html)**

</div>

* ` pyppbox = Python + People + Toolbox `
* Design for both short and long term people detecting, tracking, and re-identifying.
* Intergrate GUI for easy configurations and demo.
* Support YAML/JSON configurations -> File, raw string and ready dictionary.
* Support [[GTA_V_Dataset]](https://github.com/rathaumons/PoseTReID_DATASET) -> Real-time online and offline evaluation.
* Check our papers: 1 [[IEEE]](https://ieeexplore.ieee.org/document/9271712) | 2 [[IEEE]](https://ieeexplore.ieee.org/document/9946587) [[arxiv]](https://doi.org/10.48550/arxiv.2205.10086)

==> pyppbox-3.1b2.tar.gz: pyppbox-3.1b2/README.md <==
# 🐍📦 [**pyppbox**](https://github.com/rathaumons/pyppbox)

<div align="center">

[![Documentation](https://github.com/rathaumons/pyppbox/actions/workflows/pyppboxdocs.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/pyppboxdocs.yaml) [![Build PyPI](https://github.com/rathaumons/pyppbox/actions/workflows/build_pypi.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/build_pypi.yaml) [![Test Build](https://github.com/rathaumons/pyppbox/actions/workflows/test_build.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/test_build.yaml)

[![Test Core Windows](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_windows.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_windows.yaml) [![Test Core Linux](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_linux.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_linux.yaml) [![Test Core macOS](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_macos.yaml/badge.svg)](https://github.com/rathaumons/pyppbox/actions/workflows/test_core_macos.yaml)

<img src="https://raw.githubusercontent.com/rathaROG/screenshot/master/pyppbox/pyppbox_new_wide.png"><br />

**[📗 Documentation](https://rathaumons.github.io/pyppbox/) > [🚀 Getting started](https://rathaumons.github.io/pyppbox/getstarted.html) > [💡 Examples](https://rathaumons.github.io/pyppbox/examples.html)**

</div>

* ` pyppbox = Python + People + Toolbox `
* Design for both short and long term people detecting, tracking, and re-identifying.
* Integrate GUI for easy configurations and demo.
* Support dictionary and YAML/JSON configurations.
* Support [[GTA_V_Dataset]](https://github.com/rathaumons/PoseTReID_DATASET) -> Real-time online and offline evaluation.
* Check our papers: 1 [[IEEE]](https://ieeexplore.ieee.org/document/9271712) | 2 [[IEEE]](https://ieeexplore.ieee.org/document/9946587) [[arxiv]](https://doi.org/10.48550/arxiv.2205.10086)
